zabbix_export:
  version: '7.0'
  template_groups:
    - uuid: e960332b3f6c46a1956486d4f3f99fce
      name: 'Templates/Server hardware'
  templates:
    - uuid: 0ffde4421f524bcbac2f47fec87c0f95
      template: 'HPE Synergy by HTTP'
      name: 'HPE Synergy by HTTP'
      description: |
        This template is designed to monitor HPE Synergy by HTTP.
        It works without any external scripts and uses the script item.
        
        Setup:
          1. Link template to the host.
          2. Set the hostname or IP address of the host in the {$HPE.SYNERGY.API.HOST} macro and configure the username and password in the {$HPE.SYNERGY.API.USERNAME} and {$HPE.SYNERGY.API.PASSWORD} macros.
          3. Change the {$HPE.SYNERGY.API.SCHEME} and {$HPE.SYNERGY.API.PORT} macros if needed.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/
        
        Generated by official Zabbix template tool "Templator"
      vendor:
        name: Zabbix
        version: 7.0-0
      groups:
        - name: 'Templates/Server hardware'
      items:
        - uuid: 2f9816e8a60149f4aafdf7ffb0632224
          name: 'Get data'
          type: SCRIPT
          key: hpe.synergy.get.data
          history: '0'
          value_type: TEXT
          params: |
            var Synergy = {
            	params: {},
            	session_id: null,
            	api_version: null,
            
            	setParams: function (params) {
            		['username', 'password', 'base_url'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined' || params[field] === '') {
            				throw 'Required param is not set: ' + field + '.';
            			}
            		});
            
            		Synergy.params = params;
            		if (typeof Synergy.params.base_url === 'string' && !Synergy.params.base_url.endsWith('/')) {
            			Synergy.params.base_url += '/';
            		}
            	},
            
            	checkVersion: function () {
            		if (Synergy.api_version !== null) {
            			return;
            		}
            
            		var response, request = new HttpRequest();
            		request.addHeader('Content-Type: application/json');
            
            		response = request.post(Synergy.params.base_url + 'rest/version');
            
            		if (request.getStatus() !== 200) {
            			throw 'Get version request failed with status code ' + request.getStatus() + ': ' + response;
            		}
            
            		if (response !== null) {
            			try {
            				version_data = JSON.parse(response);
            			}
            			catch (error) {
            				throw 'Failed to parse get version response received from device API.';
            			}
            		}
            		else {
            			throw 'No data received by get version request.';
            		}
            
            		if ('currentVersion' in version_data && 'minimumVersion' in version_data) {
            			if (version_data['minimumVersion'] <= 1200 && version_data['currentVersion'] >= 1200) {
            				Synergy.api_version = 1200;
            			} else {
            				throw 'API version is not supported.';
            			}
            		} else {
            			throw 'Get version response does not contain version.';
            		}
            	},
            
            	login: function () {
            		if (Synergy.session_id !== null || Synergy.api_version === null) {
            			return;
            		}
            
            		var response, request = new HttpRequest();
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('X-API-Version: ' + Synergy.api_version);
            
            		response = request.post(Synergy.params.base_url + 'rest/login-sessions', JSON.stringify({
            			'userName': Synergy.params.username,
            			'password': Synergy.params.password
            		}));
            
            		if (request.getStatus() !== 200) {
            			throw 'Auth request failed with status code ' + request.getStatus() + ': ' + response;
            		}
            
            		if (response !== null) {
            			try {
            				auth_data = JSON.parse(response);
            			}
            			catch (error) {
            				throw 'Failed to parse auth response received from device API.';
            			}
            		}
            		else {
            			throw 'No data received by auth request.';
            		}
            
            		if ('sessionID' in auth_data) {
            			Synergy.session_id = auth_data['sessionID'];
            		} else {
            			throw 'Auth response does not contain session ID.';
            		}
            	},
            
            	logout: function () {
            		if (Synergy.session_id !== null && Synergy.api_version !== null) {
            			var response, request = new HttpRequest();
            			request.addHeader('Content-Type: application/json');
            			request.addHeader('X-API-Version: ' + Synergy.api_version);
            			response = request.delete(Synergy.params.base_url + 'rest/login-sessions');
            		}
            	},
            
            	requestData: function (method) {
            		if (Synergy.session_id === null || Synergy.api_version === null) {
            			return;
            		}
            
            		request = new HttpRequest();
            		request.addHeader('Auth: ' + Synergy.session_id);
            		request.addHeader('X-API-Version: ' + Synergy.api_version);
            
            		raw_data = request.get(Synergy.params.base_url + 'rest/' + method);
            
            		if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			throw 'Request failed with status code ' + request.getStatus() + ': ' + raw_data;
            		}
            
            		if (raw_data !== null) {
            			try {
            				return JSON.parse(raw_data);
            			}
            			catch (error) {
            				throw 'Failed to parse response received from device API.';
            			}
            		}
            		else {
            			throw 'No data received by ' + method + ' request.';
            		}
            	}
            };
            
            var methods = ['datacenters', 'enclosures', 'ethernet-networks', 'fabrics', 'fc-networks', 'hypervisor-managers', 'interconnects', 'logical-enclosures', 'racks', 'server-hardware', 'storage-pools', 'storage-systems', 'storage-volumes', 'uplink-sets'],
            	data = {};
            
            data['errors'] = {};
            
            try {
            	Synergy.setParams(JSON.parse(value));
            
            	try {
            		Synergy.checkVersion();
            	}
            	catch (error) {
            		data.errors.version = error.toString();
            	}
            
            	try {
            		Synergy.login();
            	}
            	catch (error) {
            		data.errors.auth = error.toString();
            	}
            
            	if (!('auth' in data.errors) && !('version' in data.errors)) {
            		for (var i in methods) {
            			try {
            				if (methods[i] === 'enclosures') {
            					var bays = ['applianceBays', 'crossBars', 'deviceBays', 'fanBays', 'partitions', 'powerSupplyBays', 'managerBays'];
            
            					enclosures = Synergy.requestData(methods[i]);
            
            					enclosures.members.forEach(function (enclosure) {
            						enclosure_name = enclosure.name;
            
            						for (var j in bays) {
            							bay = enclosure[bays[j]];
            
            							bay.forEach(function (b) {
            								b.enclosureName = enclosure_name;
            								enclosures.members[bays[j[b]]] = b;
            							});
            						}
            					});
            
            					data[methods[i]] = enclosures;
            				}
            				else {
            					data[methods[i]] = Synergy.requestData(methods[i]);
            				}
            			}
            			catch (error) {
            				data.errors[methods[i]] = error.toString();
            			}
            		}
            	}
            }
            catch (error) {
            	data.errors.params = error.toString();
            }
            
            try {
            	Synergy.logout();
            }
            catch (error) {
            }
            
            if (Object.keys(data.errors).length !== 0) {
            	errors = 'Failed to receive data:';
            	for (var error in data.errors) {
            		errors += '\n' + error + ' : ' + data.errors[error];
            	}
            	data.errors = errors;
            }
            else {
            	data.errors = '';
            }
            
            return JSON.stringify(data);
          description: 'The JSON with the result from requests to API.'
          timeout: '{$HPE.SYNERGY.DATA.TIMEOUT}'
          parameters:
            - name: base_url
              value: '{$HPE.SYNERGY.API.SCHEME}://{$HPE.SYNERGY.API.HOST}:{$HPE.SYNERGY.API.PORT}'
            - name: password
              value: '{$HPE.SYNERGY.API.PASSWORD}'
            - name: username
              value: '{$HPE.SYNERGY.API.USERNAME}'
          tags:
            - tag: component
              value: raw
        - uuid: 03389ced2251456a98f56418f1fbc6c5
          name: 'Get datacenters data'
          type: DEPENDENT
          key: hpe.synergy.get.datacenters
          history: '0'
          value_type: TEXT
          description: 'Data of the datacenters.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.datacenters
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 6a12ea452d444c8ca5aec2698709d979
          name: 'Get enclosures data'
          type: DEPENDENT
          key: hpe.synergy.get.enclosures
          history: '0'
          value_type: TEXT
          description: 'A list of enclosures.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.enclosures
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: c0049d63dffe4cdaafa806796051e06b
          name: 'Get errors'
          type: DEPENDENT
          key: hpe.synergy.get.errors
          value_type: TEXT
          description: 'A list of errors from API requests.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.errors
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
          triggers:
            - uuid: dba8cff13328403dae2cbda8f106b384
              expression: 'length(last(/HPE Synergy by HTTP/hpe.synergy.get.errors))>0'
              name: 'There are errors in requests to API'
              opdata: '{ITEM.LASTVALUE1}'
              priority: AVERAGE
              description: 'Zabbix has received errors from API.'
              dependencies:
                - name: 'Service is unavailable'
                  expression: 'max(/HPE Synergy by HTTP/net.tcp.service["{$HPE.SYNERGY.API.SCHEME}","{$HPE.SYNERGY.API.HOST}","{$HPE.SYNERGY.API.PORT}"],5m)=0'
              tags:
                - tag: scope
                  value: availability
        - uuid: 11b7e2c9c3ba4c71a2a5b165eea2c105
          name: 'Get ethernet networks data'
          type: DEPENDENT
          key: hpe.synergy.get.ethernet_networks
          history: '0'
          value_type: TEXT
          description: 'Data of the ethernet networks.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["ethernet-networks"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: d6d0a7fb1f0e47a792cd5197e2aa99b2
          name: 'Get fabrics data'
          type: DEPENDENT
          key: hpe.synergy.get.fabrics
          history: '0'
          value_type: TEXT
          description: 'Data of the fabrics.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.fabrics
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 789012febb2c44af8cf01b83315f6e99
          name: 'Get FC networks data'
          type: DEPENDENT
          key: hpe.synergy.get.fc_networks
          history: '0'
          value_type: TEXT
          description: 'Data of the FC networks.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["fc-networks"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 1b903d33f7ef481687db5f94a94123f5
          name: 'Get hypervisor managers data'
          type: DEPENDENT
          key: hpe.synergy.get.hypervisor_managers
          history: '0'
          value_type: TEXT
          description: 'Data of the hypervisor managers.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["hypervisor-managers"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 9724a596f61241f297f5fa8fbd538ea0
          name: 'Get interconnects data'
          type: DEPENDENT
          key: hpe.synergy.get.interconnects
          history: '0'
          value_type: TEXT
          description: 'Data of the interconnects.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.interconnects
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: bff37f5e7576433e85991ca474aae7c8
          name: 'Get logical enclosures data'
          type: DEPENDENT
          key: hpe.synergy.get.logical_enclosures
          history: '0'
          value_type: TEXT
          description: 'Data of the logical enclosures.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["logical-enclosures"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 5f44e9a2434e4773ab9d8c5664535a91
          name: 'Get racks data'
          type: DEPENDENT
          key: hpe.synergy.get.racks
          history: '0'
          value_type: TEXT
          description: 'Data of the racks.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.racks
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 066eacd86e784308a0b3ed53c7fd2482
          name: 'Get server hardware data'
          type: DEPENDENT
          key: hpe.synergy.get.server_hardware
          history: '0'
          value_type: TEXT
          description: 'Data of the server hardware.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["server-hardware"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 249afb5967c146799340487196206e01
          name: 'Get storage pools data'
          type: DEPENDENT
          key: hpe.synergy.get.storage_pools
          history: '0'
          value_type: TEXT
          description: 'Data of the storage pools.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["storage-pools"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: bab0584a38fb4e9ba3270c2882e9cef1
          name: 'Get storage systems data'
          type: DEPENDENT
          key: hpe.synergy.get.storage_systems
          history: '0'
          value_type: TEXT
          description: 'Data of the storage systems.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["storage-systems"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: f232ebaf34eb474d9596cfe573e7b3fb
          name: 'Get storage volumes data'
          type: DEPENDENT
          key: hpe.synergy.get.storage_volumes
          history: '0'
          value_type: TEXT
          description: 'Data of the storage volumes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["storage-volumes"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: d8e6a2b490ab472cb15814c19ed71e16
          name: 'Get uplink sets data'
          type: DEPENDENT
          key: hpe.synergy.get.uplink_sets
          history: '0'
          value_type: TEXT
          description: 'Data of the uplink sets.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.["uplink-sets"]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.synergy.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 86da94cecaa1424e9a22479d556d7b12
          name: 'Service ping'
          type: SIMPLE
          key: 'net.tcp.service["{$HPE.SYNERGY.API.SCHEME}","{$HPE.SYNERGY.API.HOST}","{$HPE.SYNERGY.API.PORT}"]'
          description: 'Checks if the service is running and accepting the TCP connections.'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: health
            - tag: component
              value: network
          triggers:
            - uuid: 165774c1ffab46899352a36dd32bb574
              expression: 'max(/HPE Synergy by HTTP/net.tcp.service["{$HPE.SYNERGY.API.SCHEME}","{$HPE.SYNERGY.API.HOST}","{$HPE.SYNERGY.API.PORT}"],5m)=0'
              name: 'Service is unavailable'
              priority: HIGH
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
      discovery_rules:
        - uuid: 73d93ade7489472fae4e68b05de52291
          name: 'Appliance bays discovery'
          type: DEPENDENT
          key: hpe.synergy.appliances.discovery
          description: 'A list of the appliance bays in the enclosure.'
          item_prototypes:
            - uuid: d3be63fe949c4960ba5a66c546b4ebcd
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Power state'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",bay_power_state]'
              description: |
                The power state of the appliance bay.
                
                *EFuse* - the power state of the bay - it has been EFused.
                *Reset* - the power state of the bay - it has been reset.
                *SoftReset* - the power state of the bay - it has been softly reset.
                *Unknown* - the power state of the bay is unknown.
              valuemap:
                name: 'Power state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.bayPowerState
                - type: STR_REPLACE
                  parameters:
                    - EFuse
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - SoftReset
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Reset
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '3'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 76d81ddf977f4d3481af82f8a9031b50
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].applianceBays[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 08e834ca1ea04357b13d0383cfba8503
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",model]'
              value_type: CHAR
              description: 'The model name of the appliance.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: df7ef9ae030c417e9c3a9b64d22c2bb9
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the appliance.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 7921c3c8ac07452d9a0cc47436d10aac
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Powered on'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",powered_on]'
              description: '*Yes*, if the appliance is powered on; *false*, otherwise.'
              valuemap:
                name: Boolean
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.poweredOn
                - type: BOOL_TO_DECIMAL
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: d4501f70c9e74f5dbe11ab608629c666
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                Indicates whether an appliance is present in the bay:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.devicePresence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: f352ca846fa34ba698b28f8d8883a14d
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the appliance.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 6d47ed045d904cc780c538a330ba0895
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Spare part number'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",spare_part_number]'
              value_type: CHAR
              description: 'The spare part number of the appliance.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.sparePartNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 836036ba1abb43bbaaabddaa8bb438d3
              name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status]'
              description: |
                The hardware status of the appliance:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: appliance
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: d79a138fe0cd4f918e664380af8da355
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=0'
                  name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has critical status'
                  priority: HIGH
                  description: 'The appliance [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c4acd5d5451d437ab5366b24643577be
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=4'
                  name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has warning status'
                  priority: WARNING
                  description: 'The appliance [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 7b8b298e334e409da6dabf6476c80dbf
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.appliance["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=1'
                  name: 'Appliance bay [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is disabled'
                  priority: INFO
                  description: 'The appliance [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].applianceBays'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 2ebb056eceea47d7ab8ca623504feb04
          name: 'Cross bars discovery'
          type: DEPENDENT
          key: hpe.synergy.crossbars.discovery
          description: 'SDX cross fabric module connects to all computing devices installed in the system enclosure and brings in the capability of hard partitioning. Crossbar details are relevant only for enclosures with type "SDX".'
          item_prototypes:
            - uuid: cedc8d60b7c647efbd148d020432861d
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] data'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].crossbars[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: c64e3a01454f473b888e57496ec642d3
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: HW version'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",hw_version]'
              value_type: CHAR
              description: 'The hardware version.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.hwVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: aaa521f31d2d4e04b918892e8e02911d
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",part_number]'
              value_type: CHAR
              description: 'The part number provided by the manufacturer.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 4c29bf3ba488474188104c51a483949e
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                The presence in a bay:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.presence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: b414be87e93f4f08a131d46b34b1b478
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence])=4'
                  name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is subsumed'
                  priority: AVERAGE
                  description: 'The device slot is configured to be part of another device slot.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: c7fe889af0fc43e0b73b20a99b7d193a
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'A serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 322073fa57dc49df9b12898a647fe255
              name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status]'
              description: |
                The overall health status of the crossbar:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: crossbar
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: dd23cdf994c848d4b45baf4d1716f198
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=0'
                  name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has critical status'
                  priority: HIGH
                  description: 'The crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 264dff5509fb4608b862bfd3e0510e32
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=4'
                  name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has warning status'
                  priority: WARNING
                  description: 'The crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 89e007afab2b4331877b3a7c1b6a98fb
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.crossbar["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=1'
                  name: 'Crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is disabled'
                  priority: INFO
                  description: 'The crossbar [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].crossBars'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 148ed07fd68049c6976df0bc8ccdc416
          name: 'Datacenters discovery'
          type: DEPENDENT
          key: hpe.synergy.datacenters.discovery
          description: 'A list of the datacenters.'
          item_prototypes:
            - uuid: 08830efa6eb64d7291eaa15bbfc0b851
              name: 'Datacenter [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.datacenter["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the datacenter [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.datacenters
              tags:
                - tag: component
                  value: datacenter
                - tag: component
                  value: raw
                - tag: datacenter
                  value: '{#NAME}'
            - uuid: d37c1e2376ba4da5822041ad8ff37c8a
              name: 'Datacenter [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.datacenter["{#NAME}",state]'
              description: 'The current state of the resource. The valid values include Adding, AddError, Configured, CredentialError, Refreshing, RefreshError, Removing, RemoveError, and Unmanaged.'
              valuemap:
                name: 'Rack state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - AddError
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - CredentialError
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Refreshing
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - RefreshError
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - Removing
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - RemoveError
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Unmanaged
                    - '8'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '8'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '9'
              master_item:
                key: 'hpe.synergy.datacenter["{#NAME}",data]'
              tags:
                - tag: component
                  value: datacenter
                - tag: datacenter
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 4f0d8ded588f4175911edff4efd4d1cd
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",state])=1'
                  name: 'Datacenter [{#NAME}]: Add error'
                  priority: AVERAGE
                  description: 'The adding of the datacenter [{#NAME}] has failed.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 896d145d3e3e49719a1b8e01117a5987
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",state])=3'
                  name: 'Datacenter [{#NAME}]: Has credential error'
                  priority: AVERAGE
                  description: 'The datacenter [{#NAME}] has a credential error.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 8ecd353d5f0742aaabd6f65d9a7b8897
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",state])=5'
                  name: 'Datacenter [{#NAME}]: Has refresh error'
                  priority: AVERAGE
                  description: 'The datacenter [{#NAME}] has a refresh error.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 091237538cab4e35a19c0f76b9c50539
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",state])=7'
                  name: 'Datacenter [{#NAME}]: Has remove error'
                  priority: AVERAGE
                  description: 'The datacenter [{#NAME}] has a remove error.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: b9b2a869c6364cbc8ac6eb3ff7511b29
              name: 'Datacenter [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.datacenter["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that a resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.datacenter["{#NAME}",data]'
              tags:
                - tag: component
                  value: datacenter
                - tag: datacenter
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 5dbb654f17f345de8279c8249eae3207
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",status])=0'
                  name: 'Datacenter [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The datacenter [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: d04a24eceaad4741a877fdf1c58141c5
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",status])=4'
                  name: 'Datacenter [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The datacenter [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 7c70db1e75df47aeb8b4f87a634abde9
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.datacenter["{#NAME}",status])=1'
                  name: 'Datacenter [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'the datacenter [{#NAME}] currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.datacenters
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 3cde01eb8cbb4977824dc4fd00c56a10
          name: 'Devices discovery'
          type: DEPENDENT
          key: hpe.synergy.devices.discovery
          description: 'A list of device bays in the enclosure.'
          item_prototypes:
            - uuid: 5c7b1315b123482e908229882b6e57c1
              name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].deviceBays[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: device
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 38ecff044b1d4ff88f8e99b21998181a
              name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",model]'
              value_type: CHAR
              description: 'The model name of an unsupported device occupying the bay if available.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: device
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 125d25085af54d509c6f2401a85042dc
              name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Power allocated'
              type: DEPENDENT
              key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",power_allocation]'
              units: W
              description: 'The power allocated for the enclosed blade.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerAllocationWatts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: device
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 9167abd4d23445eba156f2529cb5b827
              name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                Indicates whether a device is present:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.devicePresence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: device
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: 37ccc7acfc56466cb1a0f31e11603bcc
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence])=4'
                  name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is subsumed'
                  priority: AVERAGE
                  description: 'The device slot is configured to be part of another device slot.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: c2c012eab77d425da1c69f65a5078277
              name: 'Device [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'If available, the serial number of any device occupying the bay.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.device["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: device
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].deviceBays'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 62f5e7c29207459c80163148a6231d8a
          name: 'Enclosures discovery'
          type: DEPENDENT
          key: hpe.synergy.enclosures.discovery
          description: 'A list of enclosures resources.'
          item_prototypes:
            - uuid: fb5f6aaec9254d9b998d68d647321a28
              name: 'Enclosure [{#NAME}]: Appliance bays count'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",appliance_bay_count]'
              description: 'The number of the appliance bays in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.applianceBayCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: appliance
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 2bdee9f0f6fa49928b4cef48b9900859
              name: 'Enclosure [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the enclosure [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: e0cc3af5e941491ebbb6227f2ece06a7
              name: 'Enclosure [{#NAME}]: Device bays count'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",device_bay_count]'
              description: 'The number of the device bays in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.deviceBayCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: device
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: e17e34afe0dd4e4ea2534b7762033a83
              name: 'Enclosure [{#NAME}]: Device bays power'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",device_bay_watts]'
              units: W
              description: 'The amount of power allocated for the blades in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.deviceBayWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: device
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 732b7bbca90e458ead5558cea465f88e
              name: 'Enclosure [{#NAME}]: Power allocated for fans and management devices'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",fans_mgmt_power]'
              units: W
              description: 'The amount of the power allocated for the fans and management devices of the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.fansAndManagementDevicesWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: fan
                - tag: component
                  value: management
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: d6af8f4c7cf04fe6a41c02e6ff50b98a
              name: 'Enclosure [{#NAME}]: Fan bays count'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",fan_bay_count]'
              description: 'The number of the fan bays in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.fanBayCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 8e2740eea20d4a0fb42b0cef4c894fce
              name: 'Enclosure [{#NAME}]: Firmware baseline'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",fw_baseline_name]'
              value_type: CHAR
              description: 'The name of the current firmware baseline.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.fwBaselineName
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 145729f95cfe42f0a8e8308b856a03a2
              name: 'Enclosure [{#NAME}]: Interconnect bays count'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",interconnect_bay_count]'
              description: 'The number of the interconnect bays in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.interconnectBayCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: interconnect
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 153278ea2f8940d18024f220d922130a
              name: 'Enclosure [{#NAME}]: Interconnect bays power'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",interconnect_bay_watts]'
              units: W
              description: 'The amount of power allocated for the interconnects in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.interconnectBayWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: interconnect
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 8685fbee85b2412b8c53dc82209ca90a
              name: 'Enclosure [{#NAME}]: Min power supplies'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",min_ps]'
              description: 'The minimum number of the power supplies needed.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.minimumPowerSupplies
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 7adece9356e04a7db4e35fa1e1979e78
              name: 'Enclosure [{#NAME}]: Min power supplies for redundant power feed'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",min_ps_redundant]'
              description: 'The minimum number of the power supplies needed to fulfill the redundant line feed power mode.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.minimumPowerSuppliesForRedundantPowerFeed
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 19447ecdba484d04aff2ff3c90ccaef7
              name: 'Enclosure [{#NAME}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",model]'
              value_type: CHAR
              description: 'The enclosure model name, for example, "BladeSystem c7000 Enclosure G2.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.enclosureModel
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 2ff00b9a0e2446a88aefc5cd62ca8763
              name: 'Enclosure [{#NAME}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 3c2bf0a14a9847c9925e52aa7e6815f1
              name: 'Enclosure [{#NAME}]: Power capacity'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",power_capacity]'
              units: W
              description: 'The power capacity based on power mode.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerCapacityWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 68ad000d8b4e4bd5b2778802426ec764
              name: 'Enclosure [{#NAME}]: Total allocated power'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",power_total_allocated]'
              units: W
              description: 'The total amount of the power allocated in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerAllocatedWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: af45f99643fa40429e8401bf150cd7a1
              name: 'Enclosure [{#NAME}]: Total available power'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",power_total_available]'
              units: W
              description: 'The amount of the unallocated power in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerAvailableWatts
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 820f177f59044d28a945642f36b6a193
              name: 'Enclosure [{#NAME}]: Power supply bays count'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",ps_bay_count]'
              description: 'The number of the power supply bays in the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerSupplyBayCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 4ee9c37fd5024e3d820f74fe174a42e7
              name: 'Enclosure [{#NAME}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the enclosure.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: d70426e6912f4128a58ba0f14dd3b5a0
              name: 'Enclosure [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",state]'
              description: |
                The current resource state of the enclosure:
                
                *Adding* - the enclosure is being added;
                *Configured* - the enclosure is configured and is a part of the logical enclosure. This is the usual state for an enclosure under full management;
                *Configuring* - a transient state while the enclosure is being configured for a logical enclosure;
                *Interrupted* - the previous operation on the enclosure did not complete. The operation should be re-attempted;
                *Monitored* - the enclosure is being monitored. It is not a part of the logical enclosure and only hardware-control operations are available;
                *Pending* - there are pending operations on the enclosure. Additional operations are denied;
                *RemoveFailed* - the previous operation to remove the enclosure did not succeed. The operation should be re-attempted;
                *Removing* - the enclosure is being removed;
                *Unmanaged* - the enclosure has been discovered, but has not yet been added for the management or monitoring;
                *Unsupported* - the enclosure model or version is not currently supported by HPE OneView. It cannot be configured or monitored.
              valuemap:
                name: 'Enclosure state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configuring
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Interrupted
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Monitored
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - Pending
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - RemoveFailed
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - Removing
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Unmanaged
                    - '8'
                - type: STR_REPLACE
                  parameters:
                    - Unsupported
                    - '9'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '9'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '10'
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
            - uuid: 6947d7dc74744e05a5b2fbd6ae918f16
              name: 'Enclosure [{#NAME}]: State reason'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",state_reason]'
              description: |
                Indicates the reason why the resource in its current state:
                
                *Missing* - the enclosure is no longer connected into the frame link topology;
                *None* - no reason is available, or none applies;
                *NotAdded* - the enclosure has not been added;
                *NotOwner* - the enclosure reports being managed by something other than this HPE OneView;
                *OperationFailed* - a prior operation was interrupted;
                *Unowned* - the enclosure reports are not being under the management;
                *UnsupportedFirmware* - the firmware version of the enclosure is not supported by this version of HPE OneView;
                *UpdatingFirmware* - a firmware update is in progress.
              valuemap:
                name: 'State reason'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.stateReason
                - type: STR_REPLACE
                  parameters:
                    - Missing
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - None
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - NotAdded
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - NotOwner
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - OperationFailed
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - Unowned
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - UnsupportedFirmware
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - UpdatingFirmware
                    - '7'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '7'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '8'
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 61f81dcbb3c74f14982bd29b78f6a57b
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state_reason])=0'
                  name: 'Enclosure [{#NAME}]: Is missing'
                  priority: AVERAGE
                  description: 'The enclosure is no longer connected into the frame link topology.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6101e612efa54715a72263b4ea9d5b7d
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state_reason])=5'
                  name: 'Enclosure [{#NAME}]: Is unowned'
                  priority: AVERAGE
                  description: 'The enclosure reports are not being under the management.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: a22c6445c8e9491bbd0e08ba63c37659
              name: 'Enclosure [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",status]'
              description: |
                The overall health status of the enclosure.
                The enclosure status reflects the hardware health of the enclosure, all the bays, and the enclosure components (e.g. the enclosure mid-plane, fans, power supplies, Synergy Frame Link Modules, and Synergy Composers). It explicitly does not include the status of the other HPE OneView resources such as the blades (server hardware), the interconnects, and the drive enclosures.
                
                *Critical* - requires immediate attention.
                *Disabled* - the resource is currently not operational.
                *OK* - indicates normal/informational behavior.
                *Unknown* - the health status is not yet known or cannot be determined.
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 862f37cbe3b144b5ae70998bf7406497
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",status])=0'
                  name: 'Enclosure [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the enclosure [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 50f4cfc199564b26bf575d88ec5ba57e
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",status])=4'
                  name: 'Enclosure [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the enclosure [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c3ce50cdb5374904970903c082a98f72
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",status])=1'
                  name: 'Enclosure [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The enclosure [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 66d773b8d4794752b3ff9b5913ee32f2
              name: 'Enclosure [{#NAME}]: Type'
              type: DEPENDENT
              key: 'hpe.synergy.enclosure["{#NAME}",type]'
              value_type: CHAR
              description: 'The type of the enclosure, for example, "C7000" or "SY12000" or "SDX".'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.enclosureType
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 6h
              master_item:
                key: 'hpe.synergy.enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#NAME}'
          trigger_prototypes:
            - uuid: 7cd90689dd8147949b1da375b055c71f
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state])=3 and last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state_reason])>-1'
              name: 'Enclosure [{#NAME}]: Is interrupted'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: WARNING
              description: 'The previous operation on the enclosure did not complete. The operation should be re-attempted.'
              tags:
                - tag: scope
                  value: notice
            - uuid: 7bfc1a8cde3349cba772a6217df3e275
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state])=9 and last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state_reason])>-1'
              name: 'Enclosure [{#NAME}]: Is unsupported'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              description: 'The enclosure model or version is not currently supported by HPE OneView. It cannot be configured or monitored.'
              tags:
                - tag: scope
                  value: availability
            - uuid: ef82fad1874d4dd5918d9c33323b6ae6
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state])=6 and last(/HPE Synergy by HTTP/hpe.synergy.enclosure["{#NAME}",state_reason])>-1'
              name: 'Enclosure [{#NAME}]: Remove failed'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: WARNING
              description: 'The previous operation to remove the enclosure did not succeed. The operation should be re-attempted.'
              tags:
                - tag: scope
                  value: notice
          graph_prototypes:
            - uuid: 1f9d74b503f14765ad6a054f604f3e28
              name: 'Enclosure [{#NAME}]: Power capacity'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",power_capacity]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",power_total_allocated]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",power_total_available]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",fans_mgmt_power]'
                - sortorder: '4'
                  color: FC6EA3
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",device_bay_watts]'
                - sortorder: '5'
                  color: 6C59DC
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.enclosure["{#NAME}",interconnect_bay_watts]'
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 386a121cbef74d0d9f625eedd6ed291c
          name: 'Ethernet networks discovery'
          type: DEPENDENT
          key: hpe.synergy.ethernet.networks.discovery
          description: 'A list of the ethernet networks.'
          item_prototypes:
            - uuid: 0176e96b210b4a778b0b4b9b6fabdf3b
              name: 'Ethernet network [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.ethernet.network["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the ethernet network [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.ethernet_networks
              tags:
                - tag: component
                  value: network
                - tag: component
                  value: raw
                - tag: network
                  value: '{#NAME}'
            - uuid: 9b69d74467d6440eb98fc6c69c2f6779
              name: 'Ethernet network [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.ethernet.network["{#NAME}",state]'
              value_type: CHAR
              description: 'The current state of the resource.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.ethernet.network["{#NAME}",data]'
              tags:
                - tag: component
                  value: network
                - tag: network
                  value: '{#NAME}'
            - uuid: ec1c0f1ec9f34c7aa1d6c9509e4fc6a7
              name: 'Ethernet network [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.ethernet.network["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.ethernet.network["{#NAME}",data]'
              tags:
                - tag: component
                  value: network
                - tag: network
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: c658a58285184a82969b520d5be1f9b2
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.ethernet.network["{#NAME}",status])=0'
                  name: 'Ethernet network [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The ethernet network [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6881808352bd4588b42debf5f2703f69
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.ethernet.network["{#NAME}",status])=4'
                  name: 'Ethernet network [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The ethernet network [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: eef185ab54584c069df2a4349dff9cc7
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.ethernet.network["{#NAME}",status])=1'
                  name: 'Ethernet network [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The ethernet network [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.ethernet_networks
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 67c37bbfab9345d38ed5e576fdb7cb23
          name: 'Fabrics discovery'
          type: DEPENDENT
          key: hpe.synergy.fabrics.discovery
          description: 'A list of the fabrics.'
          item_prototypes:
            - uuid: 26e6e32676d74347abd8dbf92c649113
              name: 'Fabric [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.fabric["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the fabric [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.fabrics
              tags:
                - tag: component
                  value: fabric
                - tag: component
                  value: raw
                - tag: fabric
                  value: '{#NAME}'
            - uuid: 9f38d17239ee45d4a22e8f08dde37910
              name: 'Fabric [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.fabric["{#NAME}",state]'
              value_type: CHAR
              description: 'The current state of the resource.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.fabric["{#NAME}",data]'
              tags:
                - tag: component
                  value: fabric
                - tag: fabric
                  value: '{#NAME}'
            - uuid: 82f8bedd589643d1954f329f5f10b9b9
              name: 'Fabric [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.fabric["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.fabric["{#NAME}",data]'
              tags:
                - tag: component
                  value: fabric
                - tag: fabric
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 5f67d217108d4e7fbfcaed29f0f8564f
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fabric["{#NAME}",status])=0'
                  name: 'Fabric [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the fabric [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c546f87158ee42ba8d76aa3fd6767efa
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fabric["{#NAME}",status])=4'
                  name: 'Fabric [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the fabric [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c963ad956b0644c394bd58dbbb05858a
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fabric["{#NAME}",status])=1'
                  name: 'Fabric [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The status of the fabric [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.fabrics
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 5d5303b09c6e43748571c9ea247774be
          name: 'Fans discovery'
          type: DEPENDENT
          key: hpe.synergy.fans.discovery
          description: 'A list of the fan bays in the enclosure.'
          item_prototypes:
            - uuid: 1ee7ddcfd9734abbaef8dc345f9eb85d
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].fanBays[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 8449918637ab4f98932ca75d859546b2
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",model]'
              value_type: CHAR
              description: 'The common descriptive model of the fan.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 539f8b373baf46d7bcde5fc090f02284
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the fan.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: eb7ad5fc3d4947eda9642c2a2d440796
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                Indicates whether a fan is present:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.devicePresence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 6782d5441add454384b41d9ede2a8cf2
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Required'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",required]'
              description: 'Indicates whether the enclosure configuration requires a fan to be present in the bay.'
              valuemap:
                name: Boolean
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.deviceRequired
                - type: BOOL_TO_DECIMAL
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 16a8b59afdf04df1a070e1249fdd1a61
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the fan.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 4e6338579bea4bb7acb06e57d55365e5
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Spare part number'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",spare_part_number]'
              value_type: CHAR
              description: 'The spare part number to be used when ordering an additional or replacement fan of this type.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.sparePartNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 19171c26420f4cd894509a817c3245d8
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",state]'
              description: |
                The current state of the fan:
                
                *Degraded* - a fan is degraded;
                *Failed* -  a fan has failed;
                *Misplaced* - a fan is present, but not required in this bay, and the overall fan configuration is not compliant with the enclosure fan placement rules;
                *Missing* - a fan is required, but is not present;
                *OK* - a fan bay has no issues;
                *Unknown* - the state of a fan is unknown.
              valuemap:
                name: 'Resource state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '5'
                - type: STR_REPLACE
                  parameters:
                    - Degraded
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Failed
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Misplaced
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Missing
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '5'
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: cc28f87bd5b445c3abd07af689d8ee74
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",state])=0'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is degraded'
                  priority: AVERAGE
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is in degraded state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 113096666e074f8eadab59c0250968af
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",state])=1'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is failed'
                  priority: HIGH
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is in failed state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 63589098cc6b4e9ea7e7855e5a6b980e
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",state])=2'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is misplaced'
                  priority: WARNING
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is misplaced.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6b89f74f468942f789f75fdbb2b6cee6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",state])=3'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is missing'
                  priority: AVERAGE
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is missing.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: e9ac8ad873a04d549ed492b1c23966cb
              name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status]'
              description: |
                The overall health status of the fan:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: fan
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: 6b7b21cc6a3144edaf5fb3da2b54370f
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=0'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has critical status'
                  priority: HIGH
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 168ea39107c748d0b7008b4525ff4504
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=4'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has warning status'
                  priority: WARNING
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 41296079847b49d285e395e77f920e06
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fan["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=1'
                  name: 'Fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is disabled'
                  priority: INFO
                  description: 'The fan [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].fanBays'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 100519374fc94a4487a871224c483229
          name: 'FC networks discovery'
          type: DEPENDENT
          key: hpe.synergy.fc.networks.discovery
          description: 'A list of the FC networks.'
          item_prototypes:
            - uuid: 75ca293f7deb4d7faa669f141478f1d7
              name: 'FC network [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.fc.network["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the FC network [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.fc_networks
              tags:
                - tag: component
                  value: fc-network
                - tag: component
                  value: raw
                - tag: fc-network
                  value: '{#NAME}'
            - uuid: 1defd79827204bbcaffe79cd7a9df059
              name: 'FC network [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.fc.network["{#NAME}",state]'
              value_type: CHAR
              description: 'The current state of the resource.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.fc.network["{#NAME}",data]'
              tags:
                - tag: component
                  value: fc-network
                - tag: fc-network
                  value: '{#NAME}'
            - uuid: db0c86d17310421088cad2853d35c177
              name: 'FC network [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.fc.network["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.fc.network["{#NAME}",data]'
              tags:
                - tag: component
                  value: fc-network
                - tag: fc-network
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 38b9aba3f57f4b779f26dcf3d53090cf
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fc.network["{#NAME}",status])=0'
                  name: 'FC network [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The FC network [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: edf33e3c732442c6ac3327e995d0919e
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fc.network["{#NAME}",status])=4'
                  name: 'FC network [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The FC network [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 518a795f68bf4b81ac17332f511ffdb5
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.fc.network["{#NAME}",status])=1'
                  name: 'FC network [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The FC network [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.fc_networks
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 0ac7b7355249475eac517cbc9ac8ba83
          name: 'Managers discovery'
          type: DEPENDENT
          key: hpe.synergy.frame_link_modules.discovery
          description: 'A list of the Synergy Frame Link Module bays.'
          item_prototypes:
            - uuid: 53c899a616a24fc4990363d3f2942417
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].managerBays[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 64e7f977edf34338aa74e8acc88d98fd
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Firmware version'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",fw_version]'
              value_type: CHAR
              description: 'The firmware version of the manager.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.fwVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: c34aade5cdf1469cbab8fe97ede864ea
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Link port state'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",link_port_state]'
              description: |
                The state of the LINK port:
                
                *Disabled* - the port is disabled;
                *Linked* - the port is linked;
                *Unlinked* - the port is unlinked.
              valuemap:
                name: 'Link port state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.linkPortState
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Linked
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Unlinked
                    - '2'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '2'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: ca60cadc2c0f44e7a281e956bc34d1da
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Link port status'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",link_port_status]'
              description: |
                The status of the LINK port:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.linkPortStatus
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: d0a6196dc2984373916bbb857687d398
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",link_port_status])=0'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Link port has critical status'
                  priority: HIGH
                  description: 'The link port status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: 73fd558563794741b1416fb73ba4f173
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",link_port_status])=4'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Link port has warning status'
                  priority: WARNING
                  description: 'The link port status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: ab5f51fe1dcd4a859ffb3dff66450b33
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",link_port_status])=1'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Link port is disabled'
                  priority: INFO
                  description: 'The link port of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: capacity
            - uuid: b636ea6e5d994e728579cd5d479fe298
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: MGMT port state'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",mgmt_port_state]'
              description: |
                The state of the MGMT port:
                
                *Active* - the port is in active mode;
                *Disabled* - the port is in disabled mode;
                *I3s* - the port is configured for the deployment of an OS network traffic.
                *Other* - the port is in other mode;
                *Standby* - the port is in standby mode;
                *Unknown* - the mode of the port is not known.
              valuemap:
                name: 'MGMT port state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.mgmtPortState
                - type: STR_REPLACE
                  parameters:
                    - Active
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - I3s
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Other
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Standby
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '5'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '5'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '5'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 41a66b669b15425796f1dce9b46545c5
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: MGMT port status'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",mgmt_port_status]'
              description: |
                The status of the MGMT port:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.mgmtPortStatus
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: 514ecd9c1bbd4821ad84e5ddb042d0c6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",mgmt_port_status])=0'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: MGMT port has critical status'
                  priority: HIGH
                  description: 'The MGMT port status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 7dd75b26c54d41228199ee9e810272bc
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",mgmt_port_status])=4'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: MGMT port has warning status'
                  priority: WARNING
                  description: 'The MGMT port status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 1b7b8409bc394f22b940c09e56b3fa5c
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",mgmt_port_status])=1'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: MGMT port is disabled'
                  priority: INFO
                  description: 'The MGMT port of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 99281bb985fe46c6ac9328e2e491665e
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",model]'
              value_type: CHAR
              description: 'The model of the link module.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 90a8d8e504834e4393c3fa0bbcb5e802
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the link module.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 4a9f6da6f67545fb9ed5a8333bd1b303
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                Indicates whether a manager is present in the bay:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.devicePresence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: d47706453e8944e497ff01feaaa19aab
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence])=4'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is subsumed'
                  priority: AVERAGE
                  description: 'The device slot is configured to be part of another device slot.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 1d9ac1bcc74048df8358c148c3ed9ce4
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the link module.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: c6ee7ec806e04600b6826dbb373bcafe
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Spare part number'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",spare_part_number]'
              value_type: CHAR
              description: 'The spare part number of the link module.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.sparePartNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 0f72a6c8e89b4ea0b66bb0becae93bb1
              name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status]'
              description: |
                The health status of the link module:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: manager
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: c1d8fa7ff1fe444aaefdffdcda810e5c
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=0'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 44b30472c18a49cf9c0f7bb2f30fd184
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=4'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 34dd6fb0ed264192b7d1b46ba2778b16
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.manager["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=1'
                  name: 'Manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is disabled'
                  priority: INFO
                  description: 'The manager [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: notice
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].managerBays'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 6d77748c49de4c6c9c0319a52bec29fc
          name: 'Hypervisor managers discovery'
          type: DEPENDENT
          key: hpe.synergy.hypervisor.managers.discovery
          description: 'A list of the hypervisor managers.'
          item_prototypes:
            - uuid: c6ba70270a424762bb8baf9531f44ed9
              name: 'Hypervisor manager [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.hypervisor_manager["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the hypervisor manager [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.displayName == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.hypervisor_managers
              tags:
                - tag: component
                  value: hypervisor-manager
                - tag: component
                  value: raw
                - tag: hypervisor-manager
                  value: '{#NAME}'
            - uuid: a60a72ddc0de4a9c9b0b7be53542089c
              name: 'Hypervisor manager [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.hypervisor_manager["{#NAME}",state]'
              description: 'The current state of the resource. The valid values include Connected, Disconnected, Configuring and Error.'
              valuemap:
                name: 'Hypervisor manager state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Connected
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disconnected
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configuring
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Error
                    - '3'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '3'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
              master_item:
                key: 'hpe.synergy.hypervisor_manager["{#NAME}",data]'
              tags:
                - tag: component
                  value: hypervisor-manager
                - tag: hypervisor-manager
                  value: '{#NAME}'
            - uuid: 2f0874b4d0464fc58d64c12a04b8d738
              name: 'Hypervisor manager [{#NAME}]: State reason'
              type: DEPENDENT
              key: 'hpe.synergy.hypervisor_manager["{#NAME}",state_reason]'
              value_type: CHAR
              description: 'Indicates the reason why the resource is in its current state.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.stateReason
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.hypervisor_manager["{#NAME}",data]'
              tags:
                - tag: component
                  value: hypervisor-manager
                - tag: hypervisor-manager
                  value: '{#NAME}'
            - uuid: e5ec285a6c74478d903284ecb67d3f96
              name: 'Hypervisor manager [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.hypervisor_manager["{#NAME}",status]'
              description: |
                The current status of this resource:
                
                *Critical* - requires immediate attention;
                *Disabled* - the resource is currently not operational;
                *OK* - indicates normal/informational behavior;
                *Unknown* - the health status is not yet known or cannot be determined;
                *Warning* - requires attention soon.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.hypervisor_manager["{#NAME}",data]'
              tags:
                - tag: component
                  value: hypervisor-manager
                - tag: hypervisor-manager
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: a942a7ddfad14bb08915c7ba6c3248bc
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.hypervisor_manager["{#NAME}",status])=0'
                  name: 'Hypervisor manager [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The hypervisor manager [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: d81f11c478484d77a64049a2716865b4
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.hypervisor_manager["{#NAME}",status])=4'
                  name: 'Hypervisor manager [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The hypervisor manager [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: ea85e02ebac94ab2821659c88eb5363c
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.hypervisor_manager["{#NAME}",status])=1'
                  name: 'Hypervisor manager [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The hypervisor manager [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          trigger_prototypes:
            - uuid: fd90d819f10d43cc9b18ae5e5ee96b66
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.hypervisor_manager["{#NAME}",state])=3 and length(last(/HPE Synergy by HTTP/hpe.synergy.hypervisor_manager["{#NAME}",state_reason]))>0'
              name: 'Hypervisor manager [{#NAME}]: Is in error state'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: HIGH
              description: 'The hypervisor manager [{#NAME}] has an error.'
              tags:
                - tag: scope
                  value: availability
          master_item:
            key: hpe.synergy.get.hypervisor_managers
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.displayName
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: c05507c8d82f4354a813670620298732
          name: 'Interconnects discovery'
          type: DEPENDENT
          key: hpe.synergy.interconnects.discovery
          description: 'Interconnects are centrally managed by their containing logical interconnect. The interconnect provides a physical view of a detailed downlink and uplink port state and configuration, including the current link state, speed, port role (uplink, downlink, or stacking), current pluggable media, power state, and immediate connected neighbor.'
          item_prototypes:
            - uuid: 5c504f8c744244febae87002cd520cbd
              name: 'Interconnect [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the interconnect [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.interconnects
              tags:
                - tag: component
                  value: interconnect
                - tag: component
                  value: raw
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: dc4822f158da4577a47ec4cf920b9b90
              name: 'Interconnect [{#NAME}]: Hardware health'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",hw.health]'
              value_type: CHAR
              description: 'The health status of the interconnect hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.interconnectHardwareHealth
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: 7113bba95f38421a8bcffe77f9a3944d
              name: 'Interconnect [{#NAME}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",model]'
              value_type: CHAR
              description: 'The interconnect model.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: d3e8fc007d5e4adf899fdb3d0f786fb1
              name: 'Interconnect [{#NAME}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the interconnect.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: c2e482f840184c278c09017623fd96d1
              name: 'Interconnect [{#NAME}]: Port count'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",port_count]'
              description: 'The number of ports on the interconnect.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.portCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: 27e4c424f81940b1958e0455042bf3d3
              name: 'Interconnect [{#NAME}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the interconnect.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: 8232b536d74846d7a90ce19400418a36
              name: 'Interconnect [{#NAME}]: Spare part number'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",spare_part_number]'
              value_type: CHAR
              description: 'The spare part number of the interconnect.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.sparePartNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: bd97faaf4a4c47a1a87d97650d65a375
              name: 'Interconnect [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",state]'
              value_type: CHAR
              description: 'The current state of the resource.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
            - uuid: ac234400f7324bbea2c736c6f7afd131
              name: 'Interconnect [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.interconnect["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.interconnect["{#NAME}",data]'
              tags:
                - tag: component
                  value: interconnect
                - tag: interconnect
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: ccc001583dc6478aa3569b14b65be97d
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.interconnect["{#NAME}",status])=0'
                  name: 'Interconnect [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The interconnect [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: a6d1c63e2aa04c71bac2eaef5b693110
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.interconnect["{#NAME}",status])=4'
                  name: 'Interconnect [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The interconnect [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6649436c06c345f8a394356e8a4fe546
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.interconnect["{#NAME}",status])=1'
                  name: 'Interconnect [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The interconnect [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.interconnects
          lld_macro_paths:
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: eae31026740c4de299a5e52753eb9445
          name: 'Logical enclosures discovery'
          type: DEPENDENT
          key: hpe.synergy.logical_enclosures.discovery
          description: 'A list of the logical enclosures.'
          item_prototypes:
            - uuid: 96e5588599854754b9c7513c6786d9a6
              name: 'Logical enclosure [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.logical_enclosure["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the logical enclosure [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.logical_enclosures
              tags:
                - tag: component
                  value: logical-enclosure
                - tag: component
                  value: raw
                - tag: logical-enclosure
                  value: '{#NAME}'
            - uuid: 785f3a94e8614810b7ccc84be779ad1d
              name: 'Logical enclosure [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.logical_enclosure["{#NAME}",state]'
              description: |
                The current resource state of the logical enclosure:
                
                *Consistent* - this is the expected state of the logical enclosure. The logical enclosure configuration is consistent with the enclosure group, and the configuration of the hardware resources is consistent with the logical enclosure configuration;
                *Creating* - the logical enclosure is being created;
                *DeleteFailed* - the prior attempt to delete the logical enclosure failed. Retry the delete operation potentially with the force option. No other logical enclosure operations are allowed in this state;
                *Deleting* - the logical enclosure is being deleted;
                *Inconsistent* - the configuration of the logical enclosure differs from that of the enclosure group, or the configuration of the hardware resources is inconsistent with the logical enclosure configuration. Perform an Update from group, Reapply configuration, or Update firmware action as an appropriate to bring the configuration back into consistency;
                *Updating* - configuration changes are being applied to the hardware configuration.
              valuemap:
                name: 'Logical enclosure state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Inconsistent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Creating
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - DeleteFailed
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Deleting
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Consistent
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - Updating
                    - '5'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '5'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '6'
              master_item:
                key: 'hpe.synergy.logical_enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: logical-enclosure
                - tag: logical-enclosure
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 1c17c2f49bea47bc978698e4b8d8281b
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.logical_enclosure["{#NAME}",state])=2'
                  name: 'Logical enclosure [{#NAME}]: Delete failed'
                  priority: AVERAGE
                  description: 'Indicator that the deletion of a logical enclosure failed.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 85354d24f47d45f48c5dda86b9f22fe3
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.logical_enclosure["{#NAME}",state])=0'
                  name: 'Logical enclosure [{#NAME}]: Is inconsistent'
                  priority: AVERAGE
                  description: 'The configuration of the logical enclosure differs from that of the enclosure group, or the configuration of the hardware resources is inconsistent with the logical enclosure configuration. Perform an Update from group, Reapply configuration, or Update firmware action as an appropriate to bring the configuration back into consistency.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 0f1e0448aeaf464cb608d576eb42a481
              name: 'Logical enclosure [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.logical_enclosure["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.logical_enclosure["{#NAME}",data]'
              tags:
                - tag: component
                  value: logical-enclosure
                - tag: logical-enclosure
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: b3af6beba595455eb7774b3c609e9108
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.logical_enclosure["{#NAME}",status])=0'
                  name: 'Logical enclosure [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the logical enclosure [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 32061fadb9c74abab1a1d1371e2cf3e8
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.logical_enclosure["{#NAME}",status])=4'
                  name: 'Logical enclosure [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the logical enclosure [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c7ec2fb26b794b28b99eb321a3201fce
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.logical_enclosure["{#NAME}",status])=1'
                  name: 'Logical enclosure [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The logical enclosure [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.logical_enclosures
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: b800eed59653494cb5383e91627f0ef7
          name: 'nPar discovery'
          type: DEPENDENT
          key: hpe.synergy.npar.discovery
          description: 'Electrically isolated hardware partition (nPar). Partition details are relevant only for enclosures with type "SDX".'
          item_prototypes:
            - uuid: 440aa83c441d490491b12ef31675428e
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].partitions[?(@.partitionID == "{#PARTITION_ID}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: component
                  value: partition
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
            - uuid: 8ee334ce899341a8b1292dd84d7b0af4
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Devices count'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",device_count]'
              description: 'The number of blades in the partition.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.deviceCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
              master_item:
                key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: component
                  value: partition
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
            - uuid: e090ef309a9a4f8a98d3c5e24bd53d4d
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Health'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",health]'
              description: |
                Indicates the health of the partition and the health of its owned resources (blades and IO bays) as reported by the firmware. If a problem is detected with one of the resources, the health of the partition is reported as Degraded. If all the resources in the partition are operating correctly, the health of the partition is reported as OK.
                
                *NparDegrade* - one or more resources in the partition are unhealthy.
                *NparHealthInvalid* - a partition health is invalid.
                *NparHealthMax* - a delimiter defined by the firmware.
                *NparOk* - all the resources in the partition are healthy.
              valuemap:
                name: 'Partition health'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partitionHealth
                - type: STR_REPLACE
                  parameters:
                    - NparDegrade
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - NparHealthInvalid
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - NparHealthMax
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - NparOk
                    - '3'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '3'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
              master_item:
                key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: partition
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
              trigger_prototypes:
                - uuid: 1c85a47cfa96487f8c338afe21ad7ce3
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",health])=0'
                  name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Health is degraded'
                  priority: HIGH
                  description: 'One or more resources in the partition are unhealthy.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: fdf5fa892eda46aaa2551168e36428bc
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",health])=1'
                  name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Health is invalid'
                  priority: AVERAGE
                  description: 'The partition health is invalid.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: fc5d550b6bdd4e2a891f4faa5e51f792
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Memory'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",memory]'
              units: B
              description: 'The total memory of the partition.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.memoryMb
                - type: MULTIPLIER
                  parameters:
                    - '1048576'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: component
                  value: memory
                - tag: component
                  value: partition
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
            - uuid: b388a6aeae4e4bd4b14b0eb334b67934
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Processors Count'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",processor_count]'
              description: 'The number of processors in the partition.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processorCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
              master_item:
                key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: component
                  value: cpu
                - tag: component
                  value: partition
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
            - uuid: ed4ad1bb9a534b40af4754cf31dc87f9
              name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",status]'
              description: |
                Indicates whether the partition has been booted and also indicates its current power state:
                
                *ParStatusActive* - a partition is active when a 'poweron' operation is initiated on the partition and the firmware boot process is started;
                *ParStatusInactive* - a partition is in an inactive state after it has been created or shut down;
                *ParStatusInvalid* - a partition status is invalid;
                *ParStatusManualRepair* -  a partition under manual repair;
                *ParStatusMax* - a delimiter defined by the OA firmware;
                *ParStatusUndefined* - partition status is undefined;
                *ParStatusUnknown* - a partition might report an Unknown state after an OA restart. This state is possible when the firmware is not able to identify the correct partition state due to the internal firmware errors at an OA startup. The state is persistent and can only be cleared by force powering off of the partition from the OA. A partition in this state will not accept any partition operation except parstatus and force poweroff. Any active OS instances continue to run unhindered even when the partition is in an unknown state.
              valuemap:
                name: 'Partition status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partitionStatus
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - ParStatusActive
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusInactive
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusInvalid
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusManualRepair
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusMax
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusUndefined
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - ParStatusUnknown
                    - '6'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '6'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '6'
              master_item:
                key: 'hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: component
                  value: partition
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
                - tag: partition
                  value: '{#PARTITION_ID}'
              trigger_prototypes:
                - uuid: 1a9c705957d34bfc976c23a8b1f38e14
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.partition["{#PARTITION_ID}","{#ENCLOSURE_NAME}",status])=2'
                  name: 'Partition [{#ENCLOSURE_NAME}:{#PARTITION_ID}]: Is invalid'
                  priority: AVERAGE
                  description: 'The partition status is invalid.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
            - lld_macro: '{#PARTITION_ID}'
              path: $.partitionID
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].partitions'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 8346025282a044cd8dafc2521a596f18
          name: 'Power supplies discovery'
          type: DEPENDENT
          key: hpe.synergy.ps.discovery
          description: 'List of power supply bays in the enclosure.'
          item_prototypes:
            - uuid: 92d8618ee81742f6bb1cfdd63b51f3ea
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#ENCLOSURE_NAME}")].powerSupplyBays[?(@.bayNumber == "{#BAY_NUMBER}")].first()'
              master_item:
                key: hpe.synergy.get.enclosures
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: e748215b1d4a404ca0269909d321cdc6
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",model]'
              value_type: CHAR
              description: 'The common descriptive model of the power supply.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: e0ac31d34ab34af383e56fb1c0a9972a
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Output capacity'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",output_capacity]'
              units: W
              description: 'The output capacity of the power supply.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.outputCapacityWatts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 98c72f6e11ab4dcba08c82793de9af96
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",part_number]'
              value_type: CHAR
              description: 'The part number of the power supply.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 31cc380acfec455bbb4828d4aeae1ddc
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Presence'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",presence]'
              description: |
                Indicates whether a power supply is present:
                
                *Absent* - the device slot is empty;
                *PresenceNoOp* - the device slot is uninitialized;
                *PresenceUnknown* - the device presence is unknown;
                *Present* - the device slot has a device in it;
                *Subsumed* - the device slot is configured to be part of another device slot. Not applicable for the fan or power supply bays.
              valuemap:
                name: 'Device presence'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.devicePresence
                - type: STR_REPLACE
                  parameters:
                    - Absent
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PresenceNoOp
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - PresenceUnknown
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Present
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Subsumed
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: 87ee5abdfdcf41459dd11678469a2fb4
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",serial_number]'
              value_type: CHAR
              description: 'The unique serial number of the power supply.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: ada2815275ce488f8ec1bc7a4a536681
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Spare part number'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",spare_part_number]'
              value_type: CHAR
              description: 'The spare part number to be used when ordering an additional or replacement power supply of this type.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.sparePartNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
            - uuid: a2c1cf1e0f714e46af414d8c7427d3db
              name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",data]'
              tags:
                - tag: bay-number
                  value: '{#BAY_NUMBER}'
                - tag: component
                  value: power
                - tag: enclosure
                  value: '{#ENCLOSURE_NAME}'
              trigger_prototypes:
                - uuid: ce96e032cf49415aa341b238abcabd1b
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=0'
                  name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the power supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 711695d95bc14ddfbe54be917c5e3340
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=4'
                  name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the power supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6d286b675b7546a5b429792345867d16
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.power_supply["{#BAY_NUMBER}","{#ENCLOSURE_NAME}",status])=1'
                  name: 'Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}]: Is disabled'
                  priority: INFO
                  description: 'The status of Power Supply [{#ENCLOSURE_NAME}:{#BAY_NUMBER}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#BAY_NUMBER}'
              path: $.bayNumber
            - lld_macro: '{#ENCLOSURE_NAME}'
              path: $.enclosureName
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.members.[0].powerSupplyBays'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: de1819e3eab74663b7cbd893c12ea540
          name: 'Racks discovery'
          type: DEPENDENT
          key: hpe.synergy.racks.discovery
          description: 'A list of the racks.'
          item_prototypes:
            - uuid: 8a68ba795abd445bb6832f8fb6fa5416
              name: 'Rack [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.rack["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the rack [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.racks
              tags:
                - tag: component
                  value: rack
                - tag: component
                  value: raw
                - tag: rack
                  value: '{#NAME}'
            - uuid: 921fa76608e4437d961af2409dddde0b
              name: 'Rack [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.rack["{#NAME}",state]'
              description: 'The current state of the resource. the valid values include Adding, AddError, Configured, CredentialError, Refreshing, RefreshError, Removing, RemoveError, and Unmanaged.'
              valuemap:
                name: 'Rack state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - AddError
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - CredentialError
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Refreshing
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - RefreshError
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - Removing
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - RemoveError
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Unmanaged
                    - '8'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '8'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '9'
              master_item:
                key: 'hpe.synergy.rack["{#NAME}",data]'
              tags:
                - tag: component
                  value: rack
                - tag: rack
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 3a4eebe27b2046d3af9f6b7dca4f1aeb
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",state])=1'
                  name: 'Rack [{#NAME}]: Add error'
                  priority: AVERAGE
                  description: 'Adding the rack [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: 73d7062711f4440dad2b20865dbc79f6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",state])=3'
                  name: 'Rack [{#NAME}]: Has credential error'
                  priority: AVERAGE
                  description: 'The rack [{#NAME}] has credential error.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 32b884dfb5164ae78f6274dc6ca4e0cb
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",state])=5'
                  name: 'Rack [{#NAME}]: Has refresh error'
                  priority: AVERAGE
                  description: 'The rack [{#NAME}] has refresh error.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 9ae1160a1bc242a9a1fe3fbf3b155ea7
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",state])=7'
                  name: 'Rack [{#NAME}]: Has remove error'
                  priority: AVERAGE
                  description: 'The rack [{#NAME}] has remove error.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: b9473388000e4107b7a419611bc1b81a
              name: 'Rack [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.rack["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.rack["{#NAME}",data]'
              tags:
                - tag: component
                  value: rack
                - tag: rack
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: f03657d149374102837fef92efc0bf28
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",status])=0'
                  name: 'Rack [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The rack [{#NAME}] status is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 74b635c0c6a7412395f36ac71fe56ec8
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",status])=4'
                  name: 'Rack [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The rack [{#NAME}] status is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 1e4124bef22448f7b99b3b0ecd29a3ab
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.rack["{#NAME}",status])=1'
                  name: 'Rack [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The rack [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.racks
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: dfe04e3e5bfd4c73b0f02a6329e3149b
          name: 'Server hardware discovery'
          type: DEPENDENT
          key: hpe.synergy.server_hardware.discovery
          description: 'The server hardware resource is a representation of a physical server.'
          item_prototypes:
            - uuid: 44f23870429347fb8930669c98ded461
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Processor cores count'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware.processor["{#LOCATION}",cores_count]'
              description: 'The number of cores available per processor.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processorCoreCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: cpu
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 5c9d2faf103241879fd19b0e18774dbd
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Processors count'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware.processor["{#LOCATION}",count]'
              description: 'The number of processors installed on this server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processorCount
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: cpu
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: dd1e7364fb614b2b9177f92b2ffe42a0
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Processor speed'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware.processor["{#LOCATION}",speed]'
              units: '!MHz'
              description: 'The speed of the CPUs.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processorSpeedMhz
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: cpu
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: a62de8aa573146d1a2118abff9f43245
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Processor type'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware.processor["{#LOCATION}",type]'
              value_type: CHAR
              description: 'The type of the CPU installed on this server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processorType
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: cpu
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: ee38861bdb044352a8937fe0d13d2e45
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the server [{#SERVER_NAME}:{#LOCATION}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#LOCATION}")].first()'
              master_item:
                key: hpe.synergy.get.server_hardware
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 67d50f909325417b9c47241cda44aa6b
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Maintenance state'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",maintenance_state]'
              description: 'The maintenance flag of the Server Hardware - disruptive maintenance operations, such as firmware update, can cause many server hardware alerts to be generated in a short period of time. Example: network connectivity is lost or the server reset is detected. When this field is set, predefined alerts for this particular device are suppressed. This field is set only when firmware update is ongoing. The alerts are processed normally once firmware update operation completes. Possible values are Maintenance and Normal.'
              valuemap:
                name: 'Maintenance state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.maintenanceState
                  error_handler: DISCARD_VALUE
                - type: STR_REPLACE
                  parameters:
                    - Maintenance
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Normal
                    - '1'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '1'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 90dc2db2bb6c4a968899ef04b8e2f96e
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Maintenance state reason'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",maintenance_state_reason]'
              value_type: CHAR
              description: 'This field is set to Firmware update when the server is put under maintenance.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.maintenanceStateReason
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 7239def772f84acfbfd017e1e835e7c5
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Memory'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",memory]'
              units: B
              description: 'The amount of memory installed on this server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.memoryMb
                - type: MULTIPLIER
                  parameters:
                    - '1048576'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: memory
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 1a3dfc33d4d14d82846197e66550786d
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Migration state'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",migration_state]'
              description: |
                The state of an ongoing virtual connect manager (VCM) migration:
                
                *Migrating* - the enclosure is in the process of migrating from VCM;
                *NotApplicable* - the enclosure did not require or has already completed the migration;
                *Unknown* - the migration state is unknown.
              valuemap:
                name: 'Migration state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.migrationState
                  error_handler: DISCARD_VALUE
                - type: STR_REPLACE
                  parameters:
                    - Migrating
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - NotApplicable
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '2'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '2'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '2'
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 0b6a9c030b154aa6ae112b809bfaf498
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Model'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",model]'
              value_type: CHAR
              description: 'The model string of the full server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.model
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 21edfb42e64e42878cccf66125d28b96
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Part number'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",part_number]'
              value_type: CHAR
              description: 'The part number for this server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.partNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: a2c03713255841d38f0152a432920252
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Power state'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",power_state]'
              description: 'The current power state of the server hardware. The values are Unknown, On, Off, PoweringOn, PoweringOff or Resetting.'
              valuemap:
                name: 'Physical server power state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.powerState
                - type: STR_REPLACE
                  parameters:
                    - PoweringOff
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - PoweringOn
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Resetting
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - 'Off'
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - 'On'
                    - '5'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '5'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: power
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: eaf38e9c25fb46de8e621220bca8aed5
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Serial number'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",serial_number]'
              value_type: CHAR
              description: 'The serial number of the server hardware.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.serialNumber
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 01be2f5f8b594caaab4ec25e3955405e
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",state]'
              description: |
                The current resource state of the server hardware. The allowable values are:
                
                *Unknown* - not initialized;
                *Adding* - a server is being added;
                *NoProfileApplied* - a server successfully added;
                *Monitored* - a server is being monitored;
                *Unmanaged* - a discovered and supported server;
                *Removing* - a server is being removed;
                *RemoveFailed* - an unsuccessful server removal;
                *Removed* - a server is successfully removed;
                *ApplyingProfile* - a server is successfully removed;
                *ProfileApplied* - a profile is successfully applied;
                *RemovingProfile* - a profile is being removed;
                *ProfileError* -  an Unsuccessful profile is applied or removed;
                *Unsupported* - a server model or version is not currently supported by the appliance;
                *UpdatingFirmware* - a server firmware update is in progress.
              valuemap:
                name: 'Server hardware state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - NoProfileApplied
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Monitored
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Unmanaged
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - Removing
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - RemoveFailed
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - Removed
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - ApplyingProfile
                    - '8'
                - type: STR_REPLACE
                  parameters:
                    - ProfileApplied
                    - '9'
                - type: STR_REPLACE
                  parameters:
                    - RemovingProfile
                    - '10'
                - type: STR_REPLACE
                  parameters:
                    - ProfileError
                    - '11'
                - type: STR_REPLACE
                  parameters:
                    - Unsupported
                    - '12'
                - type: STR_REPLACE
                  parameters:
                    - UpdatingFirmware
                    - '13'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '13'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '0'
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
              trigger_prototypes:
                - uuid: ce0f72a3fe5e495cb8dd20b94a2779d6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state])=11'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Has profile error'
                  priority: AVERAGE
                  description: 'The unsuccessful profile application or removal.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 5af93ca2f30d443ea18e8cf6ce139575
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state])=0'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Is not initialized'
                  priority: WARNING
                  description: 'The server is not initialized.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: c03e5c9a910c4953bb18e6347a037ea6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state])=12'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Is unsupported'
                  priority: AVERAGE
                  description: 'The server model or version is not currently supported by the appliance.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 1364b9806a104d6d8412329d47e3e505
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state])=6'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Remove failed'
                  priority: AVERAGE
                  description: 'The previous operation to remove the server hardware did not succeed. The operation should be re-attempted.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 4c09bde33af048b7a3d7cfbcaae6ff54
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: State reason'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",state_reason]'
              value_type: CHAR
              description: |
                The reason for the current resource state of the server hardware. This only applies if the state is Unmanaged, otherwise it is set to NotApplicable. The allowable values are:
                
                *Unsupported* - a server model or version is not currently supported by the appliance;
                *UpdatingFirmware* - a server firmware update is in progress;
                *NotApplicable* - when PhysicalServerState is anything besides Unmanaged;
                *NotOwner* -  no claim on the server;
                *Inventory* - a server is added by the PDU;
                *Unconfigured* - the discovery data is incomplete or an iLO configuration has failed;
                *UnsupportedFirmware* - an iLO firmware version is below the minimum support level;
                *Interrupted* - when PhysicalServerState is a result of an operation that was terminated before completing;
                *CommunicationError* - an appliance cannot communicate with an iLO or an OA.
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.stateReason
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
            - uuid: 1fec814f88b6400ab70b9a164a25b297
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.server_hardware["{#LOCATION}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.server_hardware["{#LOCATION}",data]'
              tags:
                - tag: component
                  value: server
                - tag: location
                  value: '{#LOCATION}'
                - tag: server
                  value: '{#SERVER_NAME}'
              trigger_prototypes:
                - uuid: 7db1e7eff2624546a065863a2d821287
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",status])=0'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the server [{#SERVER_NAME}:{#LOCATION}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 5c0da62e9a704d5ca556c04dbaa8e243
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",status])=4'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the server [{#SERVER_NAME}:{#LOCATION}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 79f661ed3a764515a915ba79a009ec4c
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",status])=1'
                  name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Is disabled'
                  priority: INFO
                  description: 'The server [{#SERVER_NAME}:{#LOCATION}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          trigger_prototypes:
            - uuid: cd1156d4df6e411690f94a2857beab16
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",maintenance_state])=0 and length(last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",maintenance_state_reason]))>0'
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Is in maintenance mode'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: INFO
              description: 'The disruptive maintenance operations like firmware update can cause many server hardware alerts to be generated in a short period of time. Example: Network connectivity is lost or the server reset is detected.'
              tags:
                - tag: scope
                  value: notice
            - uuid: f74bf53c1b394aad9019b603de9a2c09
              expression: 'last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state])=4 and length(last(/HPE Synergy by HTTP/hpe.synergy.server_hardware["{#LOCATION}",state_reason]))>0'
              name: 'Server [{#SERVER_NAME}:{#LOCATION}]: Is unmanaged'
              opdata: 'Reason: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              description: 'Discovered a supported server.'
              tags:
                - tag: scope
                  value: notice
          master_item:
            key: hpe.synergy.get.server_hardware
          lld_macro_paths:
            - lld_macro: '{#LOCATION}'
              path: $.name
            - lld_macro: '{#SERVER_NAME}'
              path: $.serverName
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: a295686d8b5b4970b1ea5eb67bee55f1
          name: 'Storage pools discovery'
          type: DEPENDENT
          key: hpe.synergy.storage_pools.discovery
          description: 'A list of the storage pools.'
          item_prototypes:
            - uuid: 6f21fd88ccdb46ac83cd6a4beba12f95
              name: 'Storage pool [{#NAME}]: Capacity allocated'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools.capacity["{#NAME}",allocated]'
              units: B
              description: 'The capacity allocated from the storage pool in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.allocatedCapacity
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
            - uuid: e6ffbb837f2945418f200f8d57b8bf39
              name: 'Storage pool [{#NAME}]: Capacity free'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools.capacity["{#NAME}",free]'
              units: B
              description: 'The free capacity available from the storage pool in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.freeCapacity
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
            - uuid: b3f2dc2c62574ead8986ace6751738d0
              name: 'Storage pool [{#NAME}]: Capacity allocated to snapshots'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools.capacity["{#NAME}",snapshot]'
              units: B
              description: 'The pool capacity allocated to the snapshots in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.deviceSpecificAttributes.allocatedCapacity.snapshotAllocatedCapacity
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
            - uuid: 5d172531ae344037a94e23fd5c72165a
              name: 'Storage pool [{#NAME}]: Capacity total'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools.capacity["{#NAME}",total]'
              units: B
              description: 'The total capacity of the storage pool in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.totalCapacity
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
            - uuid: ee254d7b254641c7a5f762cbdd2dabf2
              name: 'Storage pool [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the storage pool [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.storage_pools
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
            - uuid: 52f63554126b4ee0a6fd6efdfea36356
              name: 'Storage pool [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools["{#NAME}",state]'
              description: |
                The current state of the resource:
                
                *AddFailed* - an attempt to add the resource failed;
                *Adding* - the resource is in the process of being added;
                *Configured* - the resource is configured;
                *Connected* - the appliance has connected to the resource;
                *Copying* - the resource is in the process of being copied;
                *CreateFailed* - an attempt to create the resource failed;
                *Creating* - the resource is in the process of being created;
                *DeleteFailed* - an attempt to delete the resource failed;
                *Deleting* - the resource is in the process of being deleted;
                *Discovered* - the resource has been discovered by the appliance, but it is not managed by the appliance;
                *Managed* - the resource is managed by the appliance;
                *Normal* - the resource is in a normal state;
                *UpdateFailed* - an attempt to update the resource failed;
                *Updating* - the resource is in the process of being updated.
              valuemap:
                name: 'Storage volume state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - AddFailed
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Connected
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Copying
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - CreateFailed
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - Creating
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - DeleteFailed
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Deleting
                    - '8'
                - type: STR_REPLACE
                  parameters:
                    - Discovered
                    - '9'
                - type: STR_REPLACE
                  parameters:
                    - Managed
                    - '10'
                - type: STR_REPLACE
                  parameters:
                    - Normal
                    - '11'
                - type: STR_REPLACE
                  parameters:
                    - UpdateFailed
                    - '12'
                - type: STR_REPLACE
                  parameters:
                    - Updating
                    - '13'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '13'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '14'
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: ae6ac88132f14763ba1ab0488d78d79d
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",state])=0'
                  name: 'Storage pool [{#NAME}]: Add error'
                  priority: AVERAGE
                  description: 'Adding of the storage pool [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: 439cee82cd6744d09b4597a6aeeda91a
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",state])=5'
                  name: 'Storage pool [{#NAME}]: Create failed'
                  priority: AVERAGE
                  description: 'Creating of the storage pool [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: 91031655fd16446995f316b20e2c0bed
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",state])=7'
                  name: 'Storage pool [{#NAME}]: Delete failed'
                  priority: AVERAGE
                  description: 'Deletion of the storage pool [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: d0a7155241b34e1f9dd3e01203aee3ba
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",state])=12'
                  name: 'Storage pool [{#NAME}]: Update failed'
                  priority: AVERAGE
                  description: 'Updating of the storage pool [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 9f3c42f517c64f9bb8869617438a9aff
              name: 'Storage pool [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.storage.pools["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.storage.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: pool
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: bace21ba544d45b58541a3e2affde554
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",status])=0'
                  name: 'Storage pool [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the storage pool [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: 135683c55d81457e90ba97d8e02165a6
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",status])=4'
                  name: 'Storage pool [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the storage pool [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: 4d7c963326d54600b639ec2d14babeb7
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.pools["{#NAME}",status])=1'
                  name: 'Storage pool [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The storage pool [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: capacity
          graph_prototypes:
            - uuid: a248b84392c44b4bbf9594550b35b8f8
              name: 'Storage pool [{#NAME}]: Capacity'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.pools.capacity["{#NAME}",allocated]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.pools.capacity["{#NAME}",free]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.pools.capacity["{#NAME}",snapshot]'
          master_item:
            key: hpe.synergy.get.storage_pools
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 65c71880235345d69327b8cdfbd526e6
          name: 'Storage systems discovery'
          type: DEPENDENT
          key: hpe.synergy.storage_systems.discovery
          description: 'A list of the storage systems.'
          item_prototypes:
            - uuid: f1047d18a75f4981a5d1b16ccdafce5b
              name: 'Storage system [{#NAME}]: Capacity allocated'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system.capacity["{#NAME}",allocated]'
              units: B
              description: 'The capacity allocated in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.allocatedCapacity
              master_item:
                key: 'hpe.synergy.storage.system["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
            - uuid: 501b587b1aa14263ac8d77325c8adfd3
              name: 'Storage system [{#NAME}]: Capacity free'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system.capacity["{#NAME}",free]'
              units: B
              description: 'The free capacity of the storage system in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.freeCapacity
              master_item:
                key: 'hpe.synergy.storage.system["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
            - uuid: 1ee384a67e0c49b99beaca7c682e7f54
              name: 'Storage system [{#NAME}]: Capacity total'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system.capacity["{#NAME}",total]'
              units: B
              description: 'The total capacity of the storage system in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.totalCapacity
              master_item:
                key: 'hpe.synergy.storage.system["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
            - uuid: 2f9bf8f7699945488201922c76f51675
              name: 'Storage system [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the storage system [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.storage_systems
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
            - uuid: 5de77ea6bd76408792e45e111d46c501
              name: 'Storage system [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system["{#NAME}",state]'
              description: |
                The current state of the resource:
                
                *AddFailed* - an attempt to add the resource failed;
                *Adding* - the resource is in the process of being added;
                *Configured* - the resource is configured;
                *Connected* - the appliance has connected to the resource;
                *Copying* - the resource is in the process of being copied;
                *CreateFailed* - an attempt to create the resource failed;
                *Creating* - the resource is in the process of being created;
                *DeleteFailed* - an attempt to delete the resource failed;
                *Deleting* - the resource is in the process of being deleted;
                *Discovered* - the resource has been discovered by the appliance, but it is not managed by the appliance;
                *Managed* - the resource is managed by the appliance;
                *Normal* - the resource is in a normal state;
                *UpdateFailed* - an attempt to update the resource failed;
                *Updating* - the resource is in the process of being updated.
              valuemap:
                name: 'Storage volume state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - AddFailed
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Connected
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Copying
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - CreateFailed
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - Creating
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - DeleteFailed
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Deleting
                    - '8'
                - type: STR_REPLACE
                  parameters:
                    - Discovered
                    - '9'
                - type: STR_REPLACE
                  parameters:
                    - Managed
                    - '10'
                - type: STR_REPLACE
                  parameters:
                    - Normal
                    - '11'
                - type: STR_REPLACE
                  parameters:
                    - UpdateFailed
                    - '12'
                - type: STR_REPLACE
                  parameters:
                    - Updating
                    - '13'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '13'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '14'
              master_item:
                key: 'hpe.synergy.storage.system["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: cfdbabe4ff584b96a961e395b3a4cda8
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",state])=0'
                  name: 'Storage system [{#NAME}]: Add error'
                  priority: AVERAGE
                  description: 'Adding the storage system [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: e759872ffa334bc2b73335b612238c82
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",state])=5'
                  name: 'Storage system [{#NAME}]: Create failed'
                  priority: AVERAGE
                  description: 'Creating of the storage system [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: 1df4613458b748b59d761d45f494920a
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",state])=7'
                  name: 'Storage system [{#NAME}]: Delete failed'
                  priority: AVERAGE
                  description: 'Deletion of the storage system [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 3c856acaa42e4ee0807713afba3937ac
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",state])=12'
                  name: 'Storage system [{#NAME}]: Update failed'
                  priority: AVERAGE
                  description: 'Updating of the storage system [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 5f9b2be3d232468e98451b380a624ae9
              name: 'Storage system [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.storage.system["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.storage.system["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: system
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: f8533d36153b4269916c7a9843ea8d5c
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",status])=0'
                  name: 'Storage system [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the storage system [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: fc278fec8e3d452bb953599a1cd42336
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",status])=4'
                  name: 'Storage system [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the storage system [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: 4e60a92c30ed4cf7960d7979a8e2fb77
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.system["{#NAME}",status])=1'
                  name: 'Storage system [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The storage system [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: capacity
          graph_prototypes:
            - uuid: c5c21884eb714c009dc0289f426b62e7
              name: 'Storage system [{#NAME}]: Capacity'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.system.capacity["{#NAME}",allocated]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.system.capacity["{#NAME}",free]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.system.capacity["{#NAME}",total]'
          master_item:
            key: hpe.synergy.get.storage_systems
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 8f274eade77c49abb1185f3545630653
          name: 'Storage volumes discovery'
          type: DEPENDENT
          key: hpe.synergy.storage_volumes.discovery
          description: 'A list of the storage volumes.'
          item_prototypes:
            - uuid: 6c5fcfa5f07e4c07a1a05d6a49e1e5cd
              name: 'Storage volume [{#NAME}]: Capacity allocated'
              type: DEPENDENT
              key: 'hpe.synergy.storage.volumes.capacity["{#NAME}",allocated]'
              units: B
              description: 'The capacity allocated in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.allocatedCapacity
              master_item:
                key: 'hpe.synergy.storage.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: volume
                  value: '{#NAME}'
            - uuid: 67076354bbb34d839c23873898dab4bd
              name: 'Storage volume [{#NAME}]: Capacity provisioned'
              type: DEPENDENT
              key: 'hpe.synergy.storage.volumes.capacity["{#NAME}",provisioned]'
              units: B
              description: 'The total provisioned capacity of the volume in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.provisionedCapacity
              master_item:
                key: 'hpe.synergy.storage.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: volume
                  value: '{#NAME}'
            - uuid: e02b8e2f502b4bfb8fa9fd17d2d4e416
              name: 'Storage volume [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.storage.volumes["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the storage volume [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.storage_volumes
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: storage
                - tag: volume
                  value: '{#NAME}'
            - uuid: 169c6201cabe48b89ff7591e9112394b
              name: 'Storage volume [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.storage.volumes["{#NAME}",state]'
              description: |
                The current state of the resource:
                
                *AddFailed* - an attempt to add the resource failed;
                *Adding* - the resource is in the process of being added;
                *Configured* - the resource is configured;
                *Connected* - the appliance has connected to the resource;
                *Copying* - the resource is in the process of being copied;
                *CreateFailed* - an attempt to create the resource failed;
                *Creating* - the resource is in the process of being created;
                *DeleteFailed* - an attempt to delete the resource failed;
                *Deleting* - the resource is in the process of being deleted;
                *Discovered* - the resource has been discovered by the appliance, but it is not managed by the appliance;
                *Managed* - the resource is managed by the appliance;
                *Normal* - the resource is in a normal state;
                *UpdateFailed* - an attempt to update the resource failed;
                *Updating* - the resource is in the process of being updated.
              valuemap:
                name: 'Storage volume state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: STR_REPLACE
                  parameters:
                    - AddFailed
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Adding
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - Configured
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Connected
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Copying
                    - '4'
                - type: STR_REPLACE
                  parameters:
                    - CreateFailed
                    - '5'
                - type: STR_REPLACE
                  parameters:
                    - Creating
                    - '6'
                - type: STR_REPLACE
                  parameters:
                    - DeleteFailed
                    - '7'
                - type: STR_REPLACE
                  parameters:
                    - Deleting
                    - '8'
                - type: STR_REPLACE
                  parameters:
                    - Discovered
                    - '9'
                - type: STR_REPLACE
                  parameters:
                    - Managed
                    - '10'
                - type: STR_REPLACE
                  parameters:
                    - Normal
                    - '11'
                - type: STR_REPLACE
                  parameters:
                    - UpdateFailed
                    - '12'
                - type: STR_REPLACE
                  parameters:
                    - Updating
                    - '13'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '13'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '14'
              master_item:
                key: 'hpe.synergy.storage.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: volume
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: b13d8a034a214bb5bd82d9e573d06e7b
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",state])=0'
                  name: 'Storage volume [{#NAME}]: Add error'
                  priority: AVERAGE
                  description: 'Adding the storage volume [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: 15f5b0ded7d8430d9b6338d8ab4a26e7
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",state])=5'
                  name: 'Storage volume [{#NAME}]: Create failed'
                  priority: AVERAGE
                  description: 'Creating of the storage volume [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: capacity
                    - tag: scope
                      value: notice
                - uuid: d7b4d59197dc4471b3db746c527213ae
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",state])=7'
                  name: 'Storage volume [{#NAME}]: Delete failed'
                  priority: AVERAGE
                  description: 'Deletion of the storage volume [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: c0b2dc67758446fa82c6bf9c92c76e93
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",state])=12'
                  name: 'Storage volume [{#NAME}]: Update failed'
                  priority: AVERAGE
                  description: 'Updating of the storage volume [{#NAME}] failed.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 6c9927a095e04feb808c05aa44b672d0
              name: 'Storage volume [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.storage.volumes["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.storage.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: storage
                - tag: volume
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 284d76cba28a4fc195b4b825665bc570
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",status])=0'
                  name: 'Storage volume [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the storage volume [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: ab040784159040a1ad031015e9ebef73
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",status])=4'
                  name: 'Storage volume [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the storage volume [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
                - uuid: ea9c2c2993b74859b30caaeac8871982
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.storage.volumes["{#NAME}",status])=1'
                  name: 'Storage volume [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The storage volume [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: capacity
          graph_prototypes:
            - uuid: f5530d63e0704ad884731cffc3a50051
              name: 'Storage volume [{#NAME}]: Capacity'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.volumes.capacity["{#NAME}",allocated]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE Synergy by HTTP'
                    key: 'hpe.synergy.storage.volumes.capacity["{#NAME}",provisioned]'
          master_item:
            key: hpe.synergy.get.storage_volumes
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: d4ba209881884b75b1edd7cca832be79
          name: 'Uplink sets discovery'
          type: DEPENDENT
          key: hpe.synergy.uplink_sets.discovery
          description: 'A list of the uplink sets.'
          item_prototypes:
            - uuid: 1469992463264badb3a80839414e9f2e
              name: 'Uplink set [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.synergy.uplink_set["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'Data of the uplink set [{#NAME}].'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.members[?(@.name == "{#NAME}")].first()'
              master_item:
                key: hpe.synergy.get.uplink_sets
              tags:
                - tag: component
                  value: network
                - tag: component
                  value: raw
                - tag: component
                  value: uplink-set
                - tag: uplink-set
                  value: '{#NAME}'
            - uuid: be09b2f2848d4143a396a9b0cb945ecc
              name: 'Uplink set [{#NAME}]: State'
              type: DEPENDENT
              key: 'hpe.synergy.uplink_set["{#NAME}",state]'
              value_type: CHAR
              description: 'The current state of the resource.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.synergy.uplink_set["{#NAME}",data]'
              tags:
                - tag: component
                  value: network
                - tag: component
                  value: uplink-set
                - tag: uplink-set
                  value: '{#NAME}'
            - uuid: 08fe02575307492ea4ad42a6bfa4a2a9
              name: 'Uplink set [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.synergy.uplink_set["{#NAME}",status]'
              description: |
                The overall health status of the resource. The following are the valid values for the status of the resource:
                
                *OK* - indicates normal/informational behavior;
                *Disabled* - indicates that the resource is not operational;
                *Warning* - requires attention soon;
                *Critical* - requires immediate attention;
                *Unknown* - should be avoided, but there may be rare occasions when the status is unknown.
              valuemap:
                name: 'Health status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 10m
                - type: STR_REPLACE
                  parameters:
                    - Critical
                    - '0'
                - type: STR_REPLACE
                  parameters:
                    - Disabled
                    - '1'
                - type: STR_REPLACE
                  parameters:
                    - OK
                    - '2'
                - type: STR_REPLACE
                  parameters:
                    - Unknown
                    - '3'
                - type: STR_REPLACE
                  parameters:
                    - Warning
                    - '4'
                - type: IN_RANGE
                  parameters:
                    - '0'
                    - '4'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '3'
              master_item:
                key: 'hpe.synergy.uplink_set["{#NAME}",data]'
              tags:
                - tag: component
                  value: network
                - tag: component
                  value: uplink-set
                - tag: uplink-set
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 89514e78b6e949278e83c3a2372d0fb9
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.uplink_set["{#NAME}",status])=0'
                  name: 'Uplink set [{#NAME}]: Has critical status'
                  priority: HIGH
                  description: 'The status of the uplink set [{#NAME}] is critical. Needs immediate attention.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 09f23615c85f43758a05d89466b3ca31
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.uplink_set["{#NAME}",status])=4'
                  name: 'Uplink set [{#NAME}]: Has warning status'
                  priority: WARNING
                  description: 'The status of the uplink set [{#NAME}] is warning. Needs attention soon.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 57187189c1bc4269873b51ef91a010c4
                  expression: 'last(/HPE Synergy by HTTP/hpe.synergy.uplink_set["{#NAME}",status])=1'
                  name: 'Uplink set [{#NAME}]: Is disabled'
                  priority: INFO
                  description: 'The uplink set [{#NAME}] is currently not operational.'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: hpe.synergy.get.uplink_sets
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.members
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
      tags:
        - tag: class
          value: hardware
        - tag: target
          value: hpe
        - tag: target
          value: synergy
      macros:
        - macro: '{$HPE.SYNERGY.API.HOST}'
          value: '<SET API HOST>'
          description: 'The hostname or IP address of the API host.'
        - macro: '{$HPE.SYNERGY.API.PASSWORD}'
          type: SECRET_TEXT
          description: 'Specify password for API.'
        - macro: '{$HPE.SYNERGY.API.PORT}'
          value: '443'
          description: 'The API port.'
        - macro: '{$HPE.SYNERGY.API.SCHEME}'
          value: https
          description: 'The API scheme (http/https).'
        - macro: '{$HPE.SYNERGY.API.USERNAME}'
          value: zabbix
          description: 'Specify user name for API.'
        - macro: '{$HPE.SYNERGY.DATA.TIMEOUT}'
          value: 15s
          description: 'Response timeout for API.'
      dashboards:
        - uuid: 144b6727a17542d58449cc66728c40b9
          name: 'Server overview'
          auto_start: 'NO'
          pages:
            - name: Enclosures
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE Synergy by HTTP'
                        name: 'Enclosure [{#NAME}]: Power capacity'
                    - type: STRING
                      name: reference
                      value: AAAAA
            - name: 'Storage pools'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE Synergy by HTTP'
                        name: 'Storage pool [{#NAME}]: Capacity'
                    - type: STRING
                      name: reference
                      value: AAAAB
            - name: 'Storage systems'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE Synergy by HTTP'
                        name: 'Storage system [{#NAME}]: Capacity'
                    - type: STRING
                      name: reference
                      value: AAAAC
            - name: 'Storage volumes'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE Synergy by HTTP'
                        name: 'Storage volume [{#NAME}]: Capacity'
                    - type: STRING
                      name: reference
                      value: AAAAD
      valuemaps:
        - uuid: 20d3a73c6cc84329a5dfafff29de32cc
          name: Boolean
          mappings:
            - value: '0'
              newvalue: 'No'
            - value: '1'
              newvalue: 'Yes'
        - uuid: d3641b3e94ad495f8e0c5c49984a5aa1
          name: 'Device presence'
          mappings:
            - value: '0'
              newvalue: Absent
            - value: '1'
              newvalue: PresenceNoOp
            - value: '2'
              newvalue: PresenceUnknown
            - value: '3'
              newvalue: Present
            - value: '4'
              newvalue: Subsumed
        - uuid: 082018b109e24116bbd92f0657113165
          name: 'Enclosure state'
          mappings:
            - value: '0'
              newvalue: Adding
            - value: '1'
              newvalue: Configured
            - value: '2'
              newvalue: Configuring
            - value: '3'
              newvalue: Interrupted
            - value: '4'
              newvalue: Monitored
            - value: '5'
              newvalue: Pending
            - value: '6'
              newvalue: RemoveFailed
            - value: '7'
              newvalue: Removing
            - value: '8'
              newvalue: Unmanaged
            - value: '9'
              newvalue: Unsupported
            - value: '10'
              newvalue: Unknown
        - uuid: 05742432aca048ca96684ba52bd058ae
          name: 'Health status'
          mappings:
            - value: '0'
              newvalue: Critical
            - value: '1'
              newvalue: Disabled
            - value: '2'
              newvalue: OK
            - value: '3'
              newvalue: Unknown
            - value: '4'
              newvalue: Warning
        - uuid: 6cd4b888faa442c19392b959f1605179
          name: 'Hypervisor manager state'
          mappings:
            - value: '0'
              newvalue: Connected
            - value: '1'
              newvalue: Disconnected
            - value: '2'
              newvalue: Configuring
            - value: '3'
              newvalue: Error
            - value: '4'
              newvalue: Unknown
        - uuid: 930add5553ea42668e590c9824d9e8d3
          name: 'Link port state'
          mappings:
            - value: '0'
              newvalue: Disabled
            - value: '1'
              newvalue: Linked
            - value: '2'
              newvalue: Unlinked
            - value: '3'
              newvalue: Unknown
        - uuid: 556391b7f9c045c89d28ac52a1082635
          name: 'Logical enclosure state'
          mappings:
            - value: '0'
              newvalue: Inconsistent
            - value: '1'
              newvalue: Creating
            - value: '2'
              newvalue: DeleteFailed
            - value: '3'
              newvalue: Deleting
            - value: '4'
              newvalue: Consistent
            - value: '5'
              newvalue: Updating
            - value: '6'
              newvalue: Unknown
        - uuid: e26c553cffab4766866bf25639fb89da
          name: 'Maintenance state'
          mappings:
            - value: '0'
              newvalue: Maintenance
            - value: '1'
              newvalue: Normal
            - value: '2'
              newvalue: Unknown
        - uuid: c66615691cba4abc9c7adecc29bb346b
          name: 'MGMT port state'
          mappings:
            - value: '0'
              newvalue: Active
            - value: '1'
              newvalue: Disabled
            - value: '2'
              newvalue: I3s
            - value: '3'
              newvalue: Other
            - value: '4'
              newvalue: Standby
            - value: '5'
              newvalue: Unknown
        - uuid: 6feb2826df9244a8b6b7732c98090b63
          name: 'Migration state'
          mappings:
            - value: '0'
              newvalue: Migrating
            - value: '1'
              newvalue: NotApplicable
            - value: '2'
              newvalue: Unknown
        - uuid: b878a1503ac14781a142f69a587264ed
          name: 'Partition health'
          mappings:
            - value: '0'
              newvalue: NparDegrade
            - value: '1'
              newvalue: NparHealthInvalid
            - value: '2'
              newvalue: NparHealthMax
            - value: '3'
              newvalue: NparOk
            - value: '4'
              newvalue: Unknown
        - uuid: 2c6d8b81e7ee4407b17ca06739ac71f1
          name: 'Partition status'
          mappings:
            - value: '0'
              newvalue: ParStatusActive
            - value: '1'
              newvalue: ParStatusInactive
            - value: '2'
              newvalue: ParStatusInvalid
            - value: '3'
              newvalue: ParStatusManualRepair
            - value: '4'
              newvalue: ParStatusMax
            - value: '5'
              newvalue: ParStatusUndefined
            - value: '6'
              newvalue: ParStatusUnknown
        - uuid: 7daddccc109d41f8abf1e04ba1fbd358
          name: 'Physical server power state'
          mappings:
            - value: '0'
              newvalue: PoweringOff
            - value: '1'
              newvalue: PoweringOn
            - value: '2'
              newvalue: Resetting
            - value: '3'
              newvalue: Unknown
            - value: '4'
              newvalue: 'Off'
            - value: '5'
              newvalue: 'On'
        - uuid: fe093138fdd14f7f80fa4498d91d7fa0
          name: 'Power state'
          mappings:
            - value: '0'
              newvalue: EFuse
            - value: '1'
              newvalue: Reset
            - value: '2'
              newvalue: SoftReset
            - value: '3'
              newvalue: Unknown
        - uuid: 5a4901bdd6024256afbfebee6827e103
          name: 'Rack state'
          mappings:
            - value: '0'
              newvalue: Adding
            - value: '1'
              newvalue: AddError
            - value: '2'
              newvalue: Configured
            - value: '3'
              newvalue: CredentialError
            - value: '4'
              newvalue: Refreshing
            - value: '5'
              newvalue: RefreshError
            - value: '6'
              newvalue: Removing
            - value: '7'
              newvalue: RemoveError
            - value: '8'
              newvalue: Unmanaged
            - value: '9'
              newvalue: Unknown
        - uuid: ba5903d60953477aafd313d3688c8dd8
          name: 'Resource state'
          mappings:
            - value: '0'
              newvalue: Degraded
            - value: '1'
              newvalue: Failed
            - value: '2'
              newvalue: Misplaced
            - value: '3'
              newvalue: Missing
            - value: '4'
              newvalue: OK
            - value: '5'
              newvalue: Unknown
        - uuid: a545b93c790741a29b726f04f03cbc8f
          name: 'Server hardware state'
          mappings:
            - value: '0'
              newvalue: Unknown
            - value: '1'
              newvalue: Adding
            - value: '2'
              newvalue: NoProfileApplied
            - value: '3'
              newvalue: Monitored
            - value: '4'
              newvalue: Unmanaged
            - value: '5'
              newvalue: Removing
            - value: '6'
              newvalue: RemoveFailed
            - value: '7'
              newvalue: Removed
            - value: '8'
              newvalue: ApplyingProfile
            - value: '9'
              newvalue: ProfileApplied
            - value: '10'
              newvalue: RemovingProfile
            - value: '11'
              newvalue: ProfileError
            - value: '12'
              newvalue: Unsupported
            - value: '13'
              newvalue: UpdatingFirmware
        - uuid: 2d6f2f67dc114502ae699e873130ba23
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
        - uuid: 647f5a6d2ce54e78af163f8676f3f1e0
          name: 'State reason'
          mappings:
            - value: '0'
              newvalue: Missing
            - value: '1'
              newvalue: None
            - value: '2'
              newvalue: 'Not Added'
            - value: '3'
              newvalue: 'Not Owner'
            - value: '4'
              newvalue: 'Operation Failed'
            - value: '5'
              newvalue: Unowned
            - value: '6'
              newvalue: 'Unsupported Firmware'
            - value: '7'
              newvalue: 'Updating Firmware'
            - value: '8'
              newvalue: Unknown
        - uuid: e20d58a33c3b4a8891dda5da8b86cd5a
          name: 'Storage volume state'
          mappings:
            - value: '0'
              newvalue: AddFailed
            - value: '1'
              newvalue: Adding
            - value: '2'
              newvalue: Configured
            - value: '3'
              newvalue: Connected
            - value: '4'
              newvalue: Copying
            - value: '5'
              newvalue: CreateFailed
            - value: '6'
              newvalue: Creating
            - value: '7'
              newvalue: DeleteFailed
            - value: '8'
              newvalue: Deleting
            - value: '9'
              newvalue: Discovered
            - value: '10'
              newvalue: Managed
            - value: '11'
              newvalue: Normal
            - value: '12'
              newvalue: UpdateFailed
            - value: '13'
              newvalue: Updating
            - value: '14'
              newvalue: Unknown
